@@ -5,7 +5,19 @@ function pre($_value) { if($_value === null || $_value === false || $_value ===
 function predie($_value) { pre($_value); Yii::app()->end(); }
 
 // Yii debug mode
-defined('YII_DEBUG') or define('YII_DEBUG', false);
+define('YII_DEBUG', false);
+
+// Chive phar mode
+define('CAP_ENABLED', strpos(__FILE__, "phar://") === 0);
+if(CAP_ENABLED)
+{
+    define("CAP_PATH", sys_get_temp_dir() . DIRECTORY_SEPARATOR . "chive_" . md5(__FILE__));
+    @mkdir(CAP_PATH, 0777);
+    @mkdir(CAP_PATH . DIRECTORY_SEPARATOR . "assets", 0777);
+    @mkdir(CAP_PATH . DIRECTORY_SEPARATOR . "sessions", 0777);
+    @mkdir(CAP_PATH . DIRECTORY_SEPARATOR . "user-config", 0777);
+    copy(__DIR__ . DIRECTORY_SEPARATOR . "protected/runtime/user-config/default.xml", CAP_PATH . DIRECTORY_SEPARATOR . "user-config" . DIRECTORY_SEPARATOR . "default.xml");
+}
 
 // Load Yii
 require('yii/yii.php');
@@ -18,7 +30,8 @@ if(!date_default_timezone_get())
 }
 
 // Create web application
-$app = Yii::createWebApplication('protected/config/main.php');
+$app = YiiBase::createWebApplication(__DIR__ . DIRECTORY_SEPARATOR . 'protected/config/' . (CAP_ENABLED ? 'phar' : 'main') . '.php');
+$app->getSession()->setCookieParams(array('path' => $app->getBaseUrl(false)));
 
 // Define constants
 define('BASEURL', Yii::app()->baseUrl);
@@ -27,6 +40,7 @@ define('ICONPATH', BASEURL . '/images/icons/' . Yii::app()->params->iconPack);
 $validPaths = array(
 	'site',
 	'index.php',
+    'asset',
 );
 
 if(!$app->user->isGuest)
@@ -43,7 +57,10 @@ elseif(!preg_match('/^(' . implode('|', $validPaths) . ')/i', Yii::app()->urlMan
 	{
 		$response = new AjaxResponse();
 		$response->redirectUrl = Yii::app()->createUrl('site/login');
-		$response->send();
+
+		header("Content-type: application/json");
+		echo $response->__toString();
+		$app->end();
 	}
 	else
 	{
@@ -77,7 +94,7 @@ if($app->request->isAjaxRequest)
 }
 
 // Publish messages for javascript usage
-Yii::app()->getComponent('messages')->publishJavaScriptMessages();
+$app->getComponent('messages')->publishJavaScriptMessages();
 
 // Run application
-$app->run();
+$app->run();
\ No newline at end of file
