@@ -52,6 +52,9 @@ return array(
 			'class' => 'ChiveHttpSession',
 			'sessionName' => 'chiveSession',
 			'savePath' => 'protected/runtime/sessions',
+			'cookieParams' => array(
+				 'path' => ''
+			),
 		),
 
 		'request' => array(
@@ -229,7 +232,7 @@ return array(
 	// application-level parameters
 	'params' => array(
 		'iconPack' => 'fugue',
-		'version' => '1.0.0',
+		'version' => '1.1',
 	),
 
 	// There is no source language ...
